# YTsaurus SPYT

YTsaurus - is an open source big data platform for distributed storage and processing. 

SPYT was implemented as a library allowing to connect to YTsaurus from [Apache Spark](https://spark.apache.org/).

Documentation is available on the [project web page](https://ytsaurus.tech/docs/en/user-guide/data-processing/spyt/overview).
